@@ -4,7 +4,7 @@ from PySide2.QtCore import Signal
 from SciDataTool.GUI.WAxisManager.Ui_WAxisManager import Ui_WAxisManager
 from SciDataTool.GUI.WSliceOperator.WSliceOperator import WSliceOperator
 from SciDataTool.Functions import axes_dict, rev_axes_dict
-from SciDataTool.Functions.Plot import ifft_dict
+from SciDataTool.Functions.Plot import ifft_dict, fft_dict
 
 
 EXTENSION_DICT = {
@@ -348,17 +348,19 @@ class WAxisManager(Ui_WAxisManager, QWidget):
                 w_slice.lf_value.setDisabled(True)
                 w_slice.slider.setDisabled(True)
 
-            if len(axes_list) == 1:
-                self.w_axis_2.hide()
-
         elif frozen_type == 4:
             self.w_axis_1.c_axis.setDisabled(True)
             self.w_axis_2.c_axis.setDisabled(True)
-            if axes_list[0].name in ifft_dict:
+            if axes_list[0].name in ifft_dict or axes_list[0].name in fft_dict:
                 self.w_axis_1.c_action.setDisabled(True)
-            if len(axes_list) == 2 and axes_list[1].name in ifft_dict:
+            if len(axes_list) == 2 and (
+                axes_list[1].name in ifft_dict or axes_list[0].name in fft_dict
+            ):
                 self.w_axis_2.c_action.setDisabled(True)
 
+        if len(axes_list) == 1:
+            self.w_axis_2.hide()
+
         self.w_axis_1.blockSignals(False)
         self.w_axis_2.blockSignals(False)
 
