@@ -63,6 +63,7 @@ def plot_3D_Data(
     annotation_delim=None,
     marker_color="k",
     is_shading_flat=None,
+    is_hide_annotation=False,
 ):
     """Plots a field as a function of two axes
 
@@ -186,7 +187,9 @@ def plot_3D_Data(
                 is_flat=True,
             )
     else:
-        result = self.get_along(*arg_list_along, unit=unit, is_norm=is_norm)
+        result = self.get_along(
+            *arg_list_along, axis_data=axis_data, unit=unit, is_norm=is_norm
+        )
 
     if type_plot == "scatter" and not is_fft:
         is_fft = True
@@ -549,6 +552,7 @@ def plot_3D_Data(
                 annotations=annotations,
                 annotation_threshold=annotation_threshold,
                 marker_color=marker_color,
+                is_hide_annotation=is_hide_annotation,
             )
         else:
             plot_3D(
